.\" file MASS/ginv.d
.\" copyright (C) 1994-9 W. N. Venables and B. D. Ripley
.\"
.BG
.FN ginv
.TL
Generalized Inverse of a Matrix
.DN
Calculates the Moore-Penrose generalized inverse of a matrix
`X'.
.CS
ginv(X, tol=sqrt(.Machine$double.eps))
.RA
.AG X
Matrix for which the Moore-Penrose inverse is required.
.OA
.AG tol
A relative tolerance to detect zero singular values.
.RT
A MP generalized inverse matrix for `X'.
.SH REFERENCE
Venables & Ripley, Chapter 2.
.SA
`solve', `svd', `eigen'
.EX
# The function is currently defined as
function(X, tol = sqrt(.Machine$double.eps))
{
## Generalized Inverse of a Matrix
  dnx <- dimnames(X)
  if(is.null(dnx)) dnx <- vector("list", 2)
  s <- svd(X)
  nz <- s$d > tol * s$d[1]
  structure(
    if(any(nz)) s$v[, nz] %*% (t(s$u[, nz])/s$d[nz]) else X,
    dimnames = dnx[2:1])
}
.KW algebra
.WR
