.\" file MASS/lm.ridge.d
.\" copyright (C) 1994-9 W. N. Venables and B. D. Ripley
.\"
.BG
.FN lm.ridge
.TL
Ridge Regression
.DN
Fit a linear model by ridge regression.
.CS
lm.ridge(formula, data, subset, na.action, lambda=0, model=F, 
         x=F, y=F, contrasts=NULL, ...)
.RA
.AG formula
a formula expression as for regression models, of the form 
`response ~ predictors'.
See the documentation of `formula' for other details.
.OA
.AG data
an optional data frame in which to interpret the variables occurring
in `formula'.
.AG subset
expression saying which subset of the rows of the data should  be used
in the fit. All observations are included by default.
.AG na.action
a function to filter missing data.
.AG lambda
A scalar or vector of ridge constants.
.AG model
should the model frame be returned?
.AG x
should the design matrix be returned?
.AG y
should the response be returned?
.AG contrasts
a list of contrasts to be used for some or all of
.AG ...
additional arguments to `lm.fit'.
.RT
A list with components
.RC coef
matrix of coefficients, one row for each value of `lambda'.
.RC scales
scalings used on the X matrix.
.RC Inter
was intercept included?
.RC lambda
vector of lambda values
.RC ym
mean of `y'
.RC xm
column means of `x' matrix
.RC GCV
vector of GCV values
.RC kHKB
HKB estimate of the ridge constant.
.RC kLW
L-W estimate of the ridge constant.
.SH REFERENCES
Brown, P. J. (1994)
.ul
Measurement, Regression and Calibration
Oxford.
.SA
`lm'
.EX
longley <- data.frame(y = longley.y, longley.x)
lm.ridge(y ~ ., longley)
plot(lm.ridge(y ~ ., longley, 
              lambda = seq(0,0.1,0.001)))
select(lm.ridge(y ~ ., longley,
              lambda = seq(0,0.1,0.0001)))
# modified HKB estimator is 0.0042754 
# modified L-W estimator is 0.032295 
# smallest value of GCV  at 0.0028 
.KW models
.WR
